#!/bin/bash
echo "Configuring for desktop PC"
# Tweak system files for a better NVIDIA experience
echo "options nvidia NVreg_PreserveVideoMemoryAllocations=1" | sudo tee -a /lib/modprobe.d/systemd.conf > /dev/null
echo -e "\n# Force GBM backend\nGBM_BACKEND=nvidia-drm\n__GLX_VENDOR_LIBRARY_NAME=nvidia" | sudo tee -a /etc/environment > /dev/null
sudo sed -i 's/^MODULES=()/MODULES=(nvidia nvidia_modeset nvidia_uvm nvidia_drm)/' /etc/mkinitcpio.conf
sudo sed -i 's/^GRUB_CMDLINE_LINUX_DEFAULT="loglevel=3 quiet"/GRUB_CMDLINE_LINUX_DEFAULT="loglevel=3 quiet nvidia-drm.modeset=1 nvidia_drm.fbdev=1 nvidia.NVreg_EnableGpuFirmware=0 mem_sleep_default=deep"/' /etc/default/grub
# Amend GRUB for dual booting, set the Windows install as the selected default (for now)
sudo sed -i 's/^#GRUB_DISABLE_OS_PROBER=false/GRUB_DISABLE_OS_PROBER=false/' /etc/default/grub
sudo sed -i 's/^GRUB_DEFAULT=0/GRUB_DEFAULT=2/' /etc/default/grub
# Update GRUB so it grabs the Windows install
sudo grub-mkconfig -o /boot/grub/grub.cfg
# Improve network security
echo "Making network changes"
echo -e "# Do not act as a router\nnet.ipv4.ip_forward = 0\nnet.ipv6.conf.all.forwarding = 0\n\n# SYN flood protection\nnet.ipv4.tcp_syncookies = 1\n\n# Disable ICMP redirect\nnet.ipv4.conf.all.accept_redirects = 0\nnet.ipv4.conf.default.accept_redirects = 0\nnet.ipv4.conf.all.secure_redirects = 0\nnet.ipv4.conf.default.secure_redirects = 0\nnet.ipv6.conf.all.accept_redirects = 0\nnet.ipv6.conf.default.accept_redirects = 0\n\n# Do not send ICMP redirects\nnet.ipv4.conf.all.send_redirects = 0\nnet.ipv4.conf.default.send_redirects = 0" | sudo tee -a /etc/sysctl.d/90-network.conf > /dev/null
# Install the noto fonts library
sudo pacman -S --noconfirm --needed noto-fonts noto-fonts-cjk noto-fonts-emoji
# Install Intel microcode, NVIDIA (DKMS version) and KDE Plasma (from the package list)
# Doing this in one pacman command so we only need to rebuild the kernel once
sudo pacman -S --noconfirm --needed intel-ucode nvidia-dkms nvidia-utils lib32-nvidia-utils nvidia-settings $(curl https://arch.ptmlab.co.uk/plasma-minimal.txt)
# Now the NVIDIA driver is installed, enable services for proper suspend/resume
sudo systemctl enable nvidia-suspend.service
sudo systemctl enable nvidia-hibernate.service
sudo systemctl enable nvidia-resume.service
# Enable SDDM as the display manager
sudo systemctl enable sddm.service
# We're done, prompt for reboot
echo "Setup complete, please reboot."